package com.yfd.platform.modules.algorithm.controller;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yfd.platform.config.ResponseResult;
import com.yfd.platform.modules.algorithm.domain.AlgorithmArrange;
import com.yfd.platform.modules.algorithm.service.IAlgorithmArrangeService;
import com.yfd.platform.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author zhengsl
 * @since 2025-06-06
 */
@RestController
@RequestMapping("/algorithm/algorithm-arrange")
@Api(value = "AlgorithmArrangeController", tags = "算法布点模块")
public class AlgorithmArrangeController {

    @Resource
    private IAlgorithmArrangeService algorithmArrangeService;

    @GetMapping("/getAlgorithmArrangePage")
    @ApiOperation("查询算法布点")
    public ResponseResult getAlgorithmArrangePage(Page<AlgorithmArrange> page, String stationId, String stationCode,
                                                  String arrangeName,
                                                  String businessType) {
        LambdaQueryWrapper<AlgorithmArrange> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(StrUtil.isNotBlank(stationId), AlgorithmArrange::getStationId, stationId);
        queryWrapper.eq(StrUtil.isNotBlank(stationCode), AlgorithmArrange::getStationCode, stationCode);
        queryWrapper.like(StrUtil.isNotBlank(arrangeName), AlgorithmArrange::getArrangeName, arrangeName);
        queryWrapper.eq(StrUtil.isNotBlank(businessType), AlgorithmArrange::getBusinessType, businessType);
        queryWrapper.eq(AlgorithmArrange::getDatastatus, "1");
        Page<AlgorithmArrange> arrangePage = algorithmArrangeService.page(page, queryWrapper);
        return ResponseResult.successData(arrangePage);
    }

    @GetMapping("/getAlgorithmArrangeById")
    @ApiOperation("根据Id查询算法布点")
    public ResponseResult getAlgorithmArrangeById(String id) {
        AlgorithmArrange algorithmArrange = algorithmArrangeService.getById(id);
        return ResponseResult.successData(algorithmArrange);
    }

    @PostMapping("/saveAlgorithmArrange")
    @ApiOperation("新增算法布点")
    public ResponseResult saveAlgorithmArrange(AlgorithmArrange algorithmArrange, MultipartFile file) {

        // 判断是否存在相同的方案
        LambdaQueryWrapper<AlgorithmArrange> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(AlgorithmArrange::getArrangeName, algorithmArrange.getArrangeName());
        if (algorithmArrangeService.getOne(queryWrapper) != null) {
            return ResponseResult.error("方案名称已存在");
        }
        algorithmArrange.setLastmodifier("admin");
        algorithmArrange.setLastmodifydate(LocalDateTime.now());
        algorithmArrange.setDatastatus("1");
        String id = IdUtil.fastSimpleUUID();
        algorithmArrange.setId(id);
        // 文件上传逻辑
        if (file != null && !file.isEmpty()) {
            try {
                // 上传文件
                String fileUrl = algorithmArrangeService.uploadImage(file);
                algorithmArrange.setImageUrl(fileUrl);
                algorithmArrange.setIsImageFlag("1");
            } catch (Exception e) {
                return ResponseResult.error("文件上传失败：" + e.getMessage());
            }
        }
        boolean save = algorithmArrangeService.save(algorithmArrange);
        if (!save) {
            return ResponseResult.error();
        }
        return ResponseResult.successData(algorithmArrange);
    }

    @PostMapping("/updateAlgorithmArrange")
    @ApiOperation("修改算法布点")
    public ResponseResult updateAlgorithmArrange(AlgorithmArrange algorithmArrange, MultipartFile file) {
        // 判断是否存在相同的方案
        LambdaQueryWrapper<AlgorithmArrange> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.ne(AlgorithmArrange::getId, algorithmArrange.getId()).eq(AlgorithmArrange::getArrangeName,
                algorithmArrange.getArrangeName());
        if (algorithmArrangeService.getOne(queryWrapper) != null) {
            return ResponseResult.error("方案名称已存在");
        }
        algorithmArrange.setLastmodifier(SecurityUtils.getCurrentUsername());
        algorithmArrange.setLastmodifydate(LocalDateTime.now());
        // 文件上传逻辑
        if (file != null && !file.isEmpty()) {
            try {
                // 调用服务层方法
                String fileUrl = algorithmArrangeService.uploadImage(file);
                algorithmArrange.setImageUrl(fileUrl);
                algorithmArrange.setIsImageFlag("1");
            } catch (Exception e) {
                return ResponseResult.error("文件上传失败：" + e.getMessage());
            }
        }
        boolean save = algorithmArrangeService.updateById(algorithmArrange);
        if (!save) {
            return ResponseResult.error();
        }
        return ResponseResult.success();
    }

    @PostMapping("/deleteAlgorithmArrange")
    @ApiOperation("删除布点数据")
    public ResponseResult deleteAlgorithmArrange(String id) {
        boolean b = algorithmArrangeService.removeById(id);
        if (b) {
            return ResponseResult.success();
        } else {
            return ResponseResult.error();
        }
    }

    @PostMapping("/deleteAlgorithmArrange")
    @ApiOperation("删除布点数据")
    public ResponseResult deleteAlgorithmArrange(@RequestBody List<String> ids) {
        boolean b = algorithmArrangeService.removeByIds(ids);
        if (b) {
            return ResponseResult.success();
        } else {
            return ResponseResult.error();
        }
    }

    @PostMapping("/callAlgorithmArrange")
    @ApiOperation("调用算法布点API")
    public ResponseResult callAlgorithmArrange(String id) {
        AlgorithmArrange algorithmArrange = algorithmArrangeService.callAlgorithmArrange(id);
        return ResponseResult.successData(algorithmArrange);
    }

}
